<?php

namespace Drupal\commerce_amws\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\Entity\EntityPublishedInterface;

/**
 * Defines the interface for an Amazon MWS store.
 *
 * It holds per store configuration related to Amazon MWS integration. A store
 * is essentially a marketplace for a specific seller account.
 */
interface StoreInterface extends ConfigEntityInterface, EntityPublishedInterface {

  /**
   * Indicates that the store is disabled.
   *
   * Disabled stores will not have their orders or products synchronized.
   */
  const STATUS_UNPUBLISHED = 0;

  /**
   * Indicates that the store is enabled.
   *
   * Only enabled stores will not have their orders or products synchronized.
   */
  const STATUS_PUBLISHED = 1;

  /**
   * Sets the label.
   *
   * @param string $label
   *   The label of the store.
   *
   * @return $this
   */
  public function setLabel($label);

  /**
   * Gets the seller ID.
   *
   * @return string
   *   The seller ID.
   */
  public function getSellerId();

  /**
   * Sets the seller ID.
   *
   * @param string $seller_id
   *   The seller ID.
   *
   * @return $this
   */
  public function setSellerId($seller_id);

  /**
   * Gets the marketplace ID.
   *
   * @return string
   *   The marketplace ID.
   */
  public function getMarketplaceId();

  /**
   * Sets the marketplace ID.
   *
   * @param string $marketplace_id
   *   The marketplace ID.
   *
   * @return $this
   */
  public function setMarketplaceId($marketplace_id);

  /**
   * Gets the LWA client ID.
   *
   * @return string
   *   The LWA client ID.
   */
  public function getLwaClientId();

  /**
   * Sets the LWA client ID.
   *
   * @param string $lwa_client_id
   *   The LWA client ID.
   *
   * @return $this
   */
  public function setLwaClientId($lwa_client_id);

  /**
   * Gets the LWA client secret.
   *
   * @return string
   *   The LWA client secret.
   */
  public function getLwaClientSecret();

  /**
   * Sets the LWA client secret.
   *
   * @param string $lwa_client_secret
   *   The LWA client secret.
   *
   * @return $this
   */
  public function setLwaClientSecret($lwa_client_secret);

  /**
   * Gets the LWA refresh token.
   *
   * @return string
   *   The LWA refresh token.
   */
  public function getLwaRefreshToken();

  /**
   * Sets the LWA refresh token.
   *
   * @param string $lwa_refresh_token
   *   The LWA refresh token.
   *
   * @return $this
   */
  public function setLwaRefreshToken($lwa_client_refresh_token);

  /**
   * Gets the AWS access key ID.
   *
   * @return string
   *   The AWS access key ID.
   */
  public function getAwsAccessKeyId();

  /**
   * Sets the AWS access key ID.
   *
   * @param string $aws_access_key_id
   *   The AWS access key ID.
   *
   * @return $this
   */
  public function setAwsAccessKeyId($aws_access_key_id);

  /**
   * Gets the AWS secret access key.
   *
   * @return string
   *   The AWS secret access key.
   */
  public function getAwsSecretAccessKey();

  /**
   * Sets the AWS secret access key.
   *
   * @param string $aws_secret_access_key
   *   The AWS secret access key.
   *
   * @return $this
   */
  public function setAwsSecretAccessKey($aws_secret_access_key);

}
