<?php

namespace Drupal\commerce_amws\MachineName\Field;

/**
 * Holds machine names of Operation entity fields.
 *
 * @link https://github.com/krystalcode/drupal8-coding-standards/blob/master/Fields.md#field-name-constants
 */
class Operation {

  /**
   * Holds the machine name for the feed document ID field.
   *
   * A submitted feed references a document that contains the message. The
   * document ID can be used to fetch the message.
   *
   * We currently do not store the document messages in the database because
   * otherwise it could contribute to the database getting really large. We may
   * add in the future a field for holding the message with configuration to
   * enable/disable storing the message and clean up old operations.
   */
  const FEED_DOCUMENT_ID = 'amws_feed_document_id';

  /**
   * Holds the machine name for the result feed document ID field.
   *
   * The result of a processed feed is contained in a document. The document ID
   * stored in this field can be used to fetch the message.
   *
   * We currently do not store the document messages in the database because
   * otherwise it could contribute to the database getting really large. We may
   * add in the future a field for holding the message but accompanied by
   * configuration that allows enabling/disabling storing the message and
   * cleaning up old operations.
   */
  const RESULT_FEED_DOCUMENT_ID = 'amws_result_feed_document_id';

}
