<?php

namespace Drupal\commerce_amws\MachineName\Field;

/**
 * Holds machine names of Shipping Method entity fields.
 *
 * @link https://github.com/krystalcode/drupal8-coding-standards/blob/master/Fields.md#field-name-constants
 */
class ShippingMethod {

  /**
   * Holds the machine name for the carrier code.
   *
   * Submitting a shipment via the `_POST_ORDER_FULFILLMENT_DATA_` feed requires
   * the carrier code. We provide a field on the shipping method so that site
   * managers can associate Drupal shipping methods with Amazon MWS carrier
   * codes.
   *
   * A list of of supported values can be found in the following link. It is not
   * known whether this list is up-to-date. The `Other` value - together with a
   * custom shipping method label on the corresponding field - can be used for
   * shipping methods provided by carriers other than the ones available in the
   * latest list.
   *
   * @link https://sellercentral.amazon.sg/gp/help/external/641?language=en_SG&ref=efph_641_cont_13491
   */
  const CARRIER_CODE = 'amws_carrier_code';

  /**
   * Holds the machine name for the shipping method.
   *
   * Submitting a shipment via the `_POST_ORDER_FULFILLMENT_DATA_` feed requires
   * the shipping method label. We provide a field on the shipping method so
   * that site managers can configure the label that will be send to Amazon MWS
   * for shipments that reference the Drupal shipping method.
   */
  const SHIPPING_METHOD = 'amws_shipping_method';

}
